<?php

namespace App\Controller;

use App\Entity\Realisateur;
use App\Form\RealisateurType;
use Doctrine\ORM\EntityManagerInterface;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\IsGranted;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;

class RealisateurController extends AbstractController
{
    /**
     * @Route("/real/", name="realisateur_liste")
     */
    public function indexAction(EntityManagerInterface $em) {
        $repo = $em->getRepository('App:Realisateur');
        $realisateurs = $repo->findAll();

        return $this->render('realisateur/liste.html.twig', array(
            'realisateurs'  => $realisateurs
        ));
    }

	/**
	 * @Route("/real/ajouter", name="realisateur_ajouter")
	 */
	public function ajouterAction(Request $request, EntityManagerInterface $em)
	{
		$realisateur = new Realisateur();
		$form = $this->createForm(RealisateurType::class, $realisateur);

		$form->handleRequest($request);
		if ($form->isSubmitted() && $form->isValid())
		{
			$em->persist($realisateur);
			$em->flush();
			$this->addFlash('success', 'Le réalisateur a été ajouté');
			return $this->redirectToRoute('realisateur_liste');
		}

		return $this->render('realisateur/ajouter.html.twig', array(
			'form'	=>	$form->createView(),
			//'realisateur'	=>	$realisateur
		));
	}

	/**
	 * @Route("/real/modifier/{id}", name="realisateur_modifier")
	 */
	public function modifierAction(Request $request, Realisateur $realisateur, EntityManagerInterface $em)
	{
		$form = $this->createForm(RealisateurType::class, $realisateur);
		$form->handleRequest($request);

		if ($form->isSubmitted() && $form->isValid())
		{
			$em->flush();
			$this->addFlash('success', 'Le réalisateur a été modifié');
			return $this->redirectToRoute('realisateur_liste');
		}


		return $this->render('realisateur/modifier.html.twig', array(
			'form'	=> $form->createView(),
            'realisateur'   =>  $realisateur
		));
	}

	/**
	 * @Route("/real/supprimer/{id}", name="realisateur_supprimer")
     * @IsGranted("ROLE_ADMIN")
	 */
	public function supprimerAction(Request $request, Realisateur $realisateur, EntityManagerInterface $em)
    {
        $form = $this->get('form.factory')->create();
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid())
        {
            foreach ($realisateur->getFilms() as $film)
            {
                $film->removeRealisateur($realisateur);
            }
            $em->remove($realisateur);
            $em->flush();
            $this->addFlash('success', 'Le réalisateur '.$realisateur->getNomComplet().' a bien été supprimé.');
            return $this->redirectToRoute('realisateur_liste');
        }

		return $this->render('realisateur/supprimer.html.twig', array(
			'realisateur'  =>  $realisateur,
            'form'  =>  $form->createView()
		));
	}

}
